A small library for composing weighted scoring metrics into score sets.
The crate provides:
NormalizedEval32/NormalizedEval64for combining a measure and normalization map.Weighted32/Weighted64for weighting any evaluator.DynScoreSet32/DynScoreSet64for storing heterogeneous metrics behind trait objects.
Re-exports
pub use traits::V01Error;pub use traits::prove_v01_f32;pub use traits::prove_v01_f64;
Modules
Structs
- DynScore
Set32 - A dynamic
f32score set that sums a list of evaluators. - DynScore
Set64 - A dynamic
f64score set that sums a list of evaluators. - DynScore
Set32 Builder - Builds a
DynScoreSet32. - DynScore
Set64 Builder - Builds a
DynScoreSet64. - Normalized
Eval32 - An
f32evaluator that measures a context and normalizes the result. - Normalized
Eval64 - An
f64evaluator that measures a context and normalizes the result. - Weighted32
- Applies a witnessed
[0, 1]weight to anf32evaluator. - Weighted64
- Applies a witnessed
[0, 1]weight to anf64evaluator.