Skip to main contentModule traits
Source - V01
- Witness attached to values known to be valid for the normalized
[0, 1]
scoring boundary. - V01Error
- Error returned when a value cannot be proven to be in the normalized
[0, 1] range.
- EvalF32
- Evaluates a context into an
f32 score. - EvalF64
- Evaluates a context into an
f64 score. - Map01F32
- Maps a measurement into the
[0, 1] range. - Map01F64
- Maps a measurement into the
[0, 1] range. - Measure
- Measures a context and returns a value chosen by the implementation.
- prove_v01_f32
- Proves that an
f32 value is in the normalized [0, 1] range. - prove_v01_f64
- Proves that an
f64 value is in the normalized [0, 1] range.