A small library for composing weighted scoring metrics into score sets.
The crate provides:
Metric32/Metric64for combining a measure, a normalization map, and a weight.DynScoreSet32/DynScoreSet64for storing heterogeneous metrics behind trait objects.
Re-exports
pub use traits::V01Error;pub use traits::prove_v01_f32;pub use traits::prove_v01_f64;
Modules
Structs
- DynScore
Set32 - A dynamic
f32score set that sums a list of evaluators. - DynScore
Set64 - A dynamic
f64score set that sums a list of evaluators. - DynScore
Set32 Builder - Builds a
DynScoreSet32. - DynScore
Set64 Builder - Builds a
DynScoreSet64. - Metric32
- A weighted
f32metric built from a measure and a normalization map. - Metric64
- A weighted
f64metric built from a measure and a normalization map.