Module traits

Module traits 

Structs

V01
Witness attached to values known to be valid for the normalized [0, 1] scoring boundary.

Traits

EvalF32
Evaluates a context into an f32 score.
EvalF64
Evaluates a context into an f64 score.
Map01F32
Maps a measurement into the [0, 1] range.
Map01F64
Maps a measurement into the [0, 1] range.
Measure
Measures a context and returns a value chosen by the implementation.