pub trait Measure<Ctx: ?Sized>: Send + Sync {
type Output;
// Required method
fn measure(&self, ctx: &Ctx) -> Self::Output;
}Expand description
Measures a context and returns a value chosen by the implementation.
Output is the value consumed by a corresponding Map01F32 or Map01F64
implementation.
Required Associated Types
Sourcetype Output
type Output
The value produced by Measure::measure.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".